==> sinfo_0.0.46.orig.tar.gz: sinfo-0.0.46/libprotocolasio/protocoltimerasio.cc <==
#include <boost/bind.hpp>
#include "protocoltimerasio.h"


ProtocolIOAsio::ProtocolIOAsio(asio::io_service & ioservice) : ioservice(ioservice)
{
}


boost::posix_time::ptime ProtocolIOAsio::currentTimeUTC()
{
  return boost::posix_time::microsec_clock::universal_time();
}


TheTimerObjectBase * ProtocolIOAsio::getTimer()
{
  return new TheTimerObjectAsio(ioservice);
}


void TheTimerObjectAsio::timerExpiredEvent(const asio::error_code& err)
{
  if (asio::error::operation_aborted==err)
  {
  }
  else
  {
    timerActive=false;
    if (myHandlerBase)
    {
      (*myHandlerBase)();
    }
  }
}


TheTimerObjectAsio::TheTimerObjectAsio(asio::io_service & ioservice) : ioservice(ioservice), timer(ioservice)
{
  timerActive=false;
  myHandlerBase=0;
}


TheTimerObjectAsio::~TheTimerObjectAsio()
{
  stop();
}


void TheTimerObjectAsio::startAlarmAt(const boost::posix_time::ptime & time, TimerEventHandlerBase * handler)
{
  myHandlerBase=handler;
  timer.expires_at(time);
  timer.async_wait(boost::bind(&TheTimerObjectAsio::timerExpiredEvent, this, asio::placeholders::error));
  timerActive=true;
}


void TheTimerObjectAsio::startAlarmAfter(const boost::posix_time::time_duration & expiry_time, TimerEventHandlerBase * handler)
{
  myHandlerBase=handler;
  timer.expires_from_now(expiry_time);
  timer.async_wait(boost::bind(&TheTimerObjectAsio::timerExpiredEvent, this, asio::placeholders::error));
  timerActive=true;
}


void TheTimerObjectAsio::stop()
{
  if (timerActive)
  {
    timer.cancel();
    timerActive=false;
  }
}

bool TheTimerObjectAsio::isRunning()
{
  return timerActive;
}

==> sinfo_0.0.47.orig.tar.gz: sinfo-0.0.47/libprotocolasio/protocoltimerasio.cc <==
#include <boost/bind.hpp>
#include "protocoltimerasio.h"


ProtocolIOAsio::ProtocolIOAsio(boost::asio::io_service & ioservice) : ioservice(ioservice)
{
}


boost::posix_time::ptime ProtocolIOAsio::currentTimeUTC()
{
  return boost::posix_time::microsec_clock::universal_time();
}


TheTimerObjectBase * ProtocolIOAsio::getTimer()
{
  return new TheTimerObjectAsio(ioservice);
}


void TheTimerObjectAsio::timerExpiredEvent(const boost::system::error_code& err)
{
  if (boost::asio::error::operation_aborted==err)
  {
  }
  else
  {
    timerActive=false;
    if (myHandlerBase)
    {
      (*myHandlerBase)();
    }
  }
}


TheTimerObjectAsio::TheTimerObjectAsio(boost::asio::io_service & ioservice) : ioservice(ioservice), timer(ioservice)
{
  timerActive=false;
  myHandlerBase=0;
}


TheTimerObjectAsio::~TheTimerObjectAsio()
{
  stop();
}


void TheTimerObjectAsio::startAlarmAt(const boost::posix_time::ptime & time, TimerEventHandlerBase * handler)
{
  myHandlerBase=handler;
  timer.expires_at(time);
  timer.async_wait(boost::bind(&TheTimerObjectAsio::timerExpiredEvent, this, boost::asio::placeholders::error));
  timerActive=true;
}


void TheTimerObjectAsio::startAlarmAfter(const boost::posix_time::time_duration & expiry_time, TimerEventHandlerBase * handler)
{
  myHandlerBase=handler;
  timer.expires_from_now(expiry_time);
  timer.async_wait(boost::bind(&TheTimerObjectAsio::timerExpiredEvent, this, boost::asio::placeholders::error));
  timerActive=true;
}


void TheTimerObjectAsio::stop()
{
  if (timerActive)
  {
    timer.cancel();
    timerActive=false;
  }
}

bool TheTimerObjectAsio::isRunning()
{
  return timerActive;
}
